@@ -14,17 +14,17 @@ from minos.common import (
     MinosConfig,
 )
 
-from .dispatchers import (
-    MinosSnapshotDispatcher,
+from .builders import (
+    SnapshotBuilder,
 )
 
 
-class MinosSnapshotService(PeriodicService):
+class SnapshotService(PeriodicService):
     """Minos Snapshot Service class."""
 
     def __init__(self, config: MinosConfig = None, **kwargs):
         super().__init__(**kwargs)
-        self.dispatcher = MinosSnapshotDispatcher.from_config(config=config)
+        self.dispatcher = SnapshotBuilder.from_config(config=config)
 
     async def start(self) -> None:
         """Start the service execution.
